PyXMake Developer Guide: PyXMake.Plugin.__poetry.Plugin Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | List of all members
PyXMake.Plugin.__poetry.Plugin Class Reference
Inheritance diagram for PyXMake.Plugin.__poetry.Plugin:

## Public Member Functions
| activate (self, poetry, io)

## Detailed Description

    Poetry plugin interface

Definition at line 71 of file __poetry.py.

## Member Function Documentation

## ◆ activate()

PyXMake.Plugin.__poetry.Plugin.activate | ( |  | self,
|  |  | poetry,
|  |  | io )

    Poetry plugin execution interface.

Definition at line 75 of file __poetry.py.

The documentation for this class was generated from the following file:

- src/PyXMake/Plugin/__poetry.py